pygeodesy.vector3dBase

Package pygeodesy :: Module vector3dBase |
[frames] | no frames]

# Module vector3dBase

(INTERNAL) Private, 3-D vector base class `Vector3dBase`.

A pure Python implementation of vector-based functions by (C) Chris Veness 2011-2024 published under the same MIT Licence**, see Vector-based geodesy.

Version: 25.10.25

Classes
| Vector3dBase (INTERNAL) Generic 3-D vector base class.

Variables
| __all__ = `_ALL_LAZY.vector3dBase`